@@ -1,12 +1,14 @@
 #line 10 "match.nw"
-static char rcsid[] = "$Id: match.nw,v 1.18 2006/06/12 21:03:53 nr Exp nr $";
-static char rcsname[] = "$Name: v2_11b $";
+static char rcsid[] = "$Id: match.nw,v 1.21 2008/10/06 01:03:05 nr Exp nr $";
+static char rcsname[] = "$Name: v2_12 $";
 #include <string.h>
 #include "match.h"
 static int matches(char *line, char *search) {
+    (void)rcsid; /* avoid a warning */
+    (void)rcsname; /* avoid a warning */
     return !strncmp(line,search,strlen(search));
 }
-#line 22 "match.nw"
+#line 24 "match.nw"
 int is_keyword(char *line, char *keyword) {
     char low_at_sign = '@';
     return *line==low_at_sign && matches(line+1,keyword) && 
