@@ -1,2 +1,2 @@
-void notangle (FILE* in, FILE *out, char *rootname, char *locformat);
+void emit_module_named (FILE *out, char *rootname, char *locformat);
 void read_defs(FILE *in);              /* read module definitions */
