@@ -1,6 +1,6 @@
 #line 6 "strsave.nw"
-static char rcsid[] = "$Id: strsave.nw,v 2.18 2006/06/12 21:03:53 nr Exp nr $";
-static char rcsname[] = "$Name: v2_11b $";
+static char rcsid[] = "$Id: strsave.nw,v 2.21 2008/10/06 01:03:05 nr Exp nr $";
+static char rcsname[] = "$Name: v2_12 $";
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -11,5 +11,7 @@ char *strsave (char *s) {
     char *t = malloc (strlen(s)+1);
     checkptr(t);
     strcpy(t,s);
+    (void)rcsid; /* avoid a warning */
+    (void)rcsname; /* avoid a warning */
     return t;
 }
